@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include "misc.h"
 #include "profile.h"
+#include "misc.h"
 
 
 /******************************************************************************
@@ -36,12 +36,11 @@ Profile *profile_open(const gchar *file)
 	Profile *profile;
 	ProfileList *p,*q;
 
-	if (file==NULL)
-		return NULL;
 	profile=g_malloc(sizeof(Profile));
 	profile->edit=FALSE;
-	profile->file=g_path_is_absolute(file)?g_strdup(file)
-							:g_strdup_printf("%s/%s",g_get_home_dir(),file);
+	profile->file=file!=NULL?g_path_is_absolute(file)?g_strdup(file)
+								:g_strconcat(g_get_home_dir(),"/",file,NULL)
+		:g_strconcat(g_get_home_dir(),"/.",g_basename(g_get_prgname()),NULL);
 	/* ե뤫ɤ߹ */
 	if ((fp=fopen(profile->file,"rt"))==NULL) {
 		profile->list=NULL;
@@ -164,7 +163,7 @@ gchar *profile_get_string(Profile *profile,
 {
 	ProfileList *p;
 
-	if (section==NULL || key==NULL)
+	if (profile==NULL || section==NULL || key==NULL)
 		return FALSE;
 	for (p=profile->list;p!=NULL;p=p->next)
 		if (p->type==PROFILE_DATA_TYPE_KEY
@@ -175,6 +174,46 @@ gchar *profile_get_string(Profile *profile,
 }
 
 
+/*	ե뤫ͤΥ
+	profile,ץե
+	section,
+	    key,
+	   type,
+	    RET,Хȿ,0:顼												*/
+gint profile_get_size(Profile *profile,
+						const gchar *section,const gchar *key,const guint type)
+{
+	guint8 *array;
+	gint n;
+	ProfileList *p;
+
+	if (profile==NULL || section==NULL || key==NULL)
+		return 0;
+	for (p=profile->list;p!=NULL;p=p->next)
+		if (p->type==PROFILE_DATA_TYPE_KEY
+										&& g_strcasecmp(p->section,section)==0
+										&& g_strcasecmp(p->key,key)==0)
+			break;
+	if (p==NULL)
+		return 0;
+	switch (type) {
+		case PROFILE_VALUE_TYPE_BOOL:
+			return g_strcasecmp(p->value,"true")==0
+					|| g_strcasecmp(p->value,"false")==0?sizeof(gboolean):0;
+		case PROFILE_VALUE_TYPE_INT:
+			return sizeof(gint);
+		case PROFILE_VALUE_TYPE_STRING:
+			return g_strlen(p->value)+1;
+		case PROFILE_VALUE_TYPE_ARRAY:
+			if ((array=misc_str_to_array(&n,p->value,10,FALSE))==NULL)
+				return 0;
+			g_free(array);
+			return n;
+	}
+	return 0;
+}
+
+
 /*	ե뤫ͤ
 	profile,ץե
 	section,
@@ -191,7 +230,7 @@ gboolean profile_get_value(Profile *profile,
 	gint n;
 	ProfileList *p;
 
-	if (section==NULL || key==NULL || value==NULL)
+	if (profile==NULL || section==NULL || key==NULL || value==NULL)
 		return FALSE;
 	for (p=profile->list;p!=NULL;p=p->next)
 		if (p->type==PROFILE_DATA_TYPE_KEY
@@ -247,13 +286,13 @@ gboolean profile_get_value(Profile *profile,
 	    RET,TRUE:ｪλ,FALSE:顼										*/
 gboolean profile_set_value(Profile *profile,
 						const gchar *section,const gchar *key,
-						const gpointer value,const gint size,const guint type)
+						gconstpointer value,const gint size,const guint type)
 {
 	gchar *data;
 	gint i;
 	ProfileList *p,*q=NULL;
 
-	if (section==NULL || key==NULL || value==NULL)
+	if (profile==NULL || section==NULL || key==NULL || value==NULL)
 		return FALSE;
 	for (p=profile->list;p!=NULL;q=p,p=p->next) {
 		if (p->type==PROFILE_DATA_TYPE_KEY
@@ -349,7 +388,7 @@ gboolean profile_delete_section(Profile *profile,const gchar *section)
 	gboolean result=FALSE;
 	ProfileList *p,*q;
 
-	if (section==NULL)
+	if (profile==NULL || section==NULL)
 		return FALSE;
 	for (p=profile->list;p!=NULL;p=q) {
 		q=p->next;
@@ -381,7 +420,7 @@ gboolean profile_delete_key(Profile *profile,
 	gboolean result=FALSE;
 	ProfileList *p,*q;
 
-	if (section==NULL || key==NULL)
+	if (profile==NULL || section==NULL || key==NULL)
 		return FALSE;
 	for (p=profile->list;p!=NULL;p=q) {
 		q=p->next;
@@ -402,3 +441,43 @@ gboolean profile_delete_key(Profile *profile,
 	}
 	return result;
 }
+
+
+/*	եΥ󤹤
+	profile,ץե
+	    RET,Υꥹ,NULL:顼									*/
+GList *profile_enum_section(Profile *profile)
+{
+	GList *glist=NULL;
+	ProfileList *p;
+
+	if (profile==NULL)
+		return FALSE;
+	for (p=profile->list;p!=NULL;p=p->next)
+		if (p->section!=NULL
+						&& (glist==NULL || g_list_find_custom(glist,p->section,
+												(GCompareFunc)strcmp)==NULL))
+			glist=g_list_insert_sorted(glist,p->section,(GCompareFunc)strcmp);
+	return glist;
+}
+
+
+/*	եΥ󤹤
+	profile,ץե
+	section,
+	    RET,Υꥹ,NULL:顼									*/
+GList *profile_enum_key(Profile *profile,const gchar *section)
+{
+	GList *glist=NULL;
+	ProfileList *p;
+
+	if (profile==NULL)
+		return FALSE;
+	for (p=profile->list;p!=NULL;p=p->next)
+		if (p->section!=NULL && p->key!=NULL
+										&& g_strcasecmp(p->section,section)==0
+			&& (glist==NULL
+			|| g_list_find_custom(glist,p->key,(GCompareFunc)strcmp)==NULL))
+			glist=g_list_insert_sorted(glist,p->key,(GCompareFunc)strcmp);
+	return glist;
+}
