@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include "general.h"
 #include "jump.h"
 #ifdef USE_GDKPIXBUF
-#include "print.h"
+# include "print.h"
 #endif
 #include "prop.h"
 #include "replace.h"
@@ -103,7 +103,7 @@ void command_save(gpointer callback_data,guint callback_action,
 		if ((!tmaid->overwrite || !misc_isfile(tmaid->file)
 			|| misc_message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
 										&& file_save_text(tmaid->file,tmaid)) {
-			tmaid->edit=FALSE;
+			tmaid_change_edit (tmaid, FALSE);
 			if (delete_list(&tmaid->undo)+delete_list(&tmaid->redo)>0)
 				set_menu_bar(tmaid);
 		}
@@ -153,7 +153,7 @@ void command_saveas(gpointer callback_data,guint callback_action,
 			gtk_label_set_text(GTK_LABEL(GTK_BIN(tmaid->menu_item)->child),
 																		file);
 			/*  */
-			tmaid->create=tmaid->edit=FALSE;
+			tmaid_change_edit (tmaid, FALSE);
 			g_free(tmaid->file);
 			tmaid->file=g_strdup(file);
 			delete_list(&tmaid->undo);
@@ -209,7 +209,8 @@ void command_reload(gpointer callback_data,guint callback_action,
 			tmaid->start->prev=tmaid->start->next=NULL;
 		}
 		tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
-		tmaid->edit=FALSE;
+		tmaid->select.x = -1;
+		tmaid_change_edit (tmaid, FALSE);
 		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
 					0,edit_get_width_max(tmaid)+1,
 					MAX(tmaid->drawing->allocation.width/tmaid->font_width,1),
@@ -412,7 +413,7 @@ void command_delete(gpointer callback_data,guint callback_action,
 	d->next=tmaid->undo;
 	tmaid->undo=d;
 	set_menu_bar(tmaid);
-	tmaid->edit=TRUE;
+	tmaid_change_edit (tmaid, TRUE);
 }
 
 
@@ -464,7 +465,7 @@ void command_valchr(gpointer callback_data,guint callback_action,
 		tmaid->undo=d;
 		if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
 			set_menu_bar(tmaid);
-		tmaid->edit=TRUE;
+		tmaid_change_edit (tmaid, TRUE);
 	}
 }
 
@@ -695,7 +696,7 @@ void command_replace(gpointer callback_data,guint callback_action,
 			tmaid->undo=d;
 			if (delete_list(&tmaid->redo)>0 || d->next==NULL)
 				set_menu_bar(tmaid);
-			tmaid->edit=TRUE;
+			tmaid_change_edit (tmaid, TRUE);
 		} while (result!=REPLACE_CANCEL);
 		if (!replace) {
 			text=g_strdup_printf(_("'%s' was not fount."),find_text[0]);
