@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -409,12 +409,17 @@ TmaidWindow *file_open_edit(const gchar *file)
 	/* ٥ */
 	tmaid->label=gtk_label_new(text);
 	g_free(text);
+	/* ޡ */
+	tmaid->mark = gtk_label_new ("*");
 	/* ɽ */
-	hbox=gtk_hbox_new(FALSE,4);
+	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),tmaid->label,TRUE,TRUE,0);
+	gtk_box_pack_start (GTK_BOX (hbox), tmaid->mark, FALSE, FALSE, 0);
 	gtk_box_pack_end(GTK_BOX(hbox),button,FALSE,FALSE,0);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook),table,hbox);
-	gtk_widget_show_all(hbox);
+	gtk_widget_show (hbox);
+	gtk_widget_show (tmaid->label);
+	gtk_widget_show_all (button);
 	gtk_widget_show_all(table);
 	gtk_notebook_set_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_page_num(GTK_NOTEBOOK(notebook),table));
