@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <string.h>
 #include <gdk/gdkkeysyms.h>
 #include "abort.h"
 #include "charset.h"
@@ -81,7 +80,7 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 	cursor=tmaid->cursor;
 	tmaid->cursor.x=edit_get_align_pos(tmaid,
 										tmaid->cursor.x,tmaid->cursor.y,FALSE);
-	length0=strlen(find);
+	length0=g_strlen(find);
 	for (i=0;i<256;i++)
 		if (charset->length[i]>max)
 			max=charset->length[i];
@@ -100,7 +99,7 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 			edit_cpy_sel_mem(tmaid,&st,&ed,text);
 			text[i]='\0';
 			if (ignorecase)	/* ʸ/ʸ̤ */
-				result=strcmp(find,text)==0;
+				result=g_strcmp(find,text)==0;
 			else			/* ʸ/ʸ̤ʤ */
 				result=g_strcasecmp(find,text)==0;
 			if (result)
@@ -138,7 +137,7 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 					/* ʸ */
 					if (data.x+charset->length[(gint)(guchar)q->text[data.x]]
 																<=q->length) {
-						memcpy(text+length1,q->text+data.x,
+						g_memmove(text+length1,q->text+data.x,
 								charset->length[(gint)(guchar)q->text[data.x]]
 															*sizeof(gchar));
 						for (i=0;
@@ -175,7 +174,7 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 			text[length1]='\0';
 			/*  */
 			if (ignorecase)	/* ʸ/ʸ̤ */
-				result=strcmp(find,text)==0;
+				result=g_strcmp(find,text)==0;
 			else			/* ʸ/ʸ̤ʤ */
 				result=g_strcasecmp(find,text)==0;
 			if (result) {
@@ -205,8 +204,8 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 				p=p->next;
 			}
 			length1-=buf[0];
-			memmove(text,text+buf[0],length1*sizeof(gchar));
-			memmove(buf,buf+buf[0],length1*sizeof(gint));
+			g_memmove(text,text+buf[0],length1*sizeof(gchar));
+			g_memmove(buf,buf+buf[0],length1*sizeof(gint));
 		}
 	} else {
 		/*  */
@@ -220,9 +219,9 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 						&& (ed.y<data.y || (data.y==ed.y && ed.x<data.x))) {
 				if (0<data.x) {
 					/* ʸ */
-					memmove(text+type[data.x-1],text,length1*sizeof(gchar));
-					memmove(buf+type[data.x-1],buf,length1*sizeof(gint));
-					memcpy(text,q->text+data.x-type[data.x-1],
+					g_memmove(text+type[data.x-1],text,length1*sizeof(gchar));
+					g_memmove(buf+type[data.x-1],buf,length1*sizeof(gint));
+					g_memmove(text,q->text+data.x-type[data.x-1],
 												type[data.x-1]*sizeof(gchar));
 					for (i=0;i<type[data.x-1];i++)
 						buf[i]=i+1;
@@ -238,8 +237,8 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 					type=g_realloc(type,q->length*sizeof(gint));
 					make_char_type(type,q->text,q->length);
 					if (!q->margin) {
-						memmove(text+1,text,length1*sizeof(gchar));
-						memmove(buf+1,buf,length1*sizeof(gint));
+						g_memmove(text+1,text,length1*sizeof(gchar));
+						g_memmove(buf+1,buf,length1*sizeof(gint));
 						text[0]='\n';
 						buf[0]=1;
 						length1++;
@@ -251,7 +250,7 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 			text[length1]='\0';
 			/*  */
 			if (ignorecase)	/* ʸ/ʸ̤ */
-				result=strcmp(find,text)==0;
+				result=g_strcmp(find,text)==0;
 			else			/* ʸ/ʸ̤ʤ */
 				result=g_strcasecmp(find,text)==0;
 			if (result) {
@@ -336,7 +335,7 @@ static void find_dialog_clicked(GtkWidget *widget,FindString *fd)
 /* ȥ꡼ǥ꥿󤬲줿 */
 static void find_dialog_activate(GtkWidget *widget,FindString *fd)
 {
-	if (strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0)
+	if (g_strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0)
 		find_dialog_clicked(widget,fd);
 }
 
@@ -345,7 +344,7 @@ static void find_dialog_activate(GtkWidget *widget,FindString *fd)
 static void find_dialog_changed(GtkWidget *widget,GtkWidget *button)
 {
 	gtk_widget_set_sensitive(button,
-							strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
+							g_strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
 }
 
 
@@ -446,7 +445,7 @@ gboolean find_dialog(FindString *fd)
 
 	/* ɽ */
 	gtk_widget_set_sensitive(button0,
-			strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)))>0);
+		g_strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)))>0);
 	gtk_widget_grab_focus(GTK_COMBO(combo)->entry);
 	find_clicked_ok=FALSE;
 
