@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,31 +23,31 @@
 #include "tmaid.h"
 
 
-typedef struct find {
+typedef struct FindString_Tag {
 	gboolean arrow;
 	gboolean ignorecase;
 	gchar *text;
-} FIND,*LPFIND;
+} FindString;
 
 
-extern gboolean find_arrow;					/* ̐ݒ */
-extern gboolean find_ignorecase;			/* ̐ݒ */
-extern gchar *find_text[32];				/* 镶 */
-extern gint find_num;						/* o^Ă錟 */
+extern gboolean find_arrow;					/*  */
+extern gboolean find_ignorecase;			/*  */
+extern gchar *find_text[32];				/* ʸ */
+extern gint find_num;						/* ϿƤ븡ʸ */
 
 
 /*	
-	       ptw,TXTEChE
-	     start,͈
-	       end,͈(x=-1ȂΑI͈͂Ȃ)
-	      find,
+	     tmaid,TXTɥ
+	     start,ϰ
+	       end,ϰ(x=-1ʤϰϤʤ)
+	      find,ʸ
 	     arrow,TRUE:,FALSE:
-	ignorecase,TRUE:啶ʂ,FALSE:啶ʂȂ	*/
-void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
-							gchar *find,gboolean arrow,gboolean ignorecase);
+	ignorecase,TRUE:ʸʸ̤,FALSE:ʸʸ̤ʤ	*/
+void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
+			const gchar *find,const gboolean arrow,const gboolean ignorecase);
 
 
-gboolean find_dialog(FIND *fd);
+gboolean find_dialog(FindString *fd);
 
 
 #endif
