@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -555,6 +555,23 @@ gboolean prompt_close(TmaidWindow *tmaid)
 }
 
 
+/*	֤ԽѤߥޡѹ
+	  tmaid,ɥ
+	is_edit,TRUE:ԽѤ,FALSE:̤Խ										*/
+void
+tmaid_change_edit (TmaidWindow *tmaid, gboolean is_edit)
+{
+	if (tmaid->edit != is_edit)
+	  {
+		tmaid->edit = is_edit;
+		if (is_edit)
+			gtk_widget_show (tmaid->mark);
+		else
+			gtk_widget_hide (tmaid->mark);
+	  }
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ٥ؿ                                                              *
@@ -613,7 +630,7 @@ void margin_operation(TmaidWindow *tmaid)
 		p=p->next;
 	}
 	tmaid->limit=limit;
-	tmaid->edit=TRUE;
+	tmaid_change_edit (tmaid, TRUE);
 	tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
 	tmaid->select.x=-1;
 	misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
@@ -680,7 +697,7 @@ void tab_operation(TmaidWindow *tmaid)
 		}
 		p=p->next;
 	}
-	tmaid->edit=TRUE;
+	tmaid_change_edit (tmaid, TRUE);
 	tmaid->select.x=-1;
 	set_menu_bar(tmaid);
 	gtk_widget_draw(tmaid->drawing,NULL);
