@@ -20,8 +20,6 @@
 #ifdef USE_GDKPIXBUF
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <stdio.h>
-#include <string.h>
 #include "abort.h"
 #include "charset.h"
 #include "edit.h"
@@ -243,7 +241,7 @@ static void print_dialog_ok_sensitive(GtkWidget *widget,PrintConfig *prncfg)
 	row=left>=0 && top>=0 && right>=0 && bottom>=0 && width>0 && height>0
 			?column*prncfg->font_width*height/(width*prncfg->font_height):0;
 	gtk_widget_set_sensitive(button1,column>=1 && row>=1
-		&& strlen(gtk_entry_get_text(GTK_ENTRY(gtk_toggle_button_get_active(
+		&& g_strlen(gtk_entry_get_text(GTK_ENTRY(gtk_toggle_button_get_active(
 								GTK_TOGGLE_BUTTON(radio0))?entry0:entry1)))>0);
 }
 
@@ -280,7 +278,7 @@ static void print_dialog_changed_combo(GtkWidget *widget,gpointer user_data)
 
 	name=gtk_entry_get_text(GTK_ENTRY(widget));
 	for (i=0;paper[i].name!=NULL;i++)
-		if (strcmp(paper[i].name,name)==0)
+		if (g_strcmp(paper[i].name,name)==0)
 			break;
 	if (paper[i].name==NULL) {
 		/* 桼 */
@@ -383,7 +381,7 @@ static void print_dialog_activate(GtkWidget *widget,PrintConfig *prncfg)
 	left=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin4));
 	right=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin5));
 	bottom=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin6));
-	if (strlen(gtk_entry_get_text(GTK_ENTRY(gtk_toggle_button_get_active(
+	if (g_strlen(gtk_entry_get_text(GTK_ENTRY(gtk_toggle_button_get_active(
 								GTK_TOGGLE_BUTTON(radio0))?entry0:entry1)))>0
 		&& gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0))>=2
 		&& left>=0 && top>=0 && right>=0 && bottom>=0
