@@ -17,7 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
-#include <string.h>
 #include "find.h"
 #include "replace.h"
 
@@ -64,7 +63,7 @@ static void replace_dialog_clicked_all(GtkWidget *widget,ReplaceString *rp)
 /* ȥ꡼ǥ꥿󤬲줿 */
 static void replace_dialog_activate(GtkWidget *widget,ReplaceString *rp)
 {
-	if (strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0)
+	if (g_strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0)
 		replace_dialog_clicked_ok(widget,rp);
 }
 
@@ -73,9 +72,9 @@ static void replace_dialog_activate(GtkWidget *widget,ReplaceString *rp)
 static void replace_dialog_changed(GtkWidget *widget,gpointer user_data)
 {
 	gtk_widget_set_sensitive(button0,
-							strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
+							g_strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
 	gtk_widget_set_sensitive(button1,
-							strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
+							g_strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
 }
 
 
@@ -206,9 +205,9 @@ gint replace_dialog(ReplaceString *rp)
 
 	/* ɽ */
 	gtk_widget_set_sensitive(button0,
-			strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0);
+		g_strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0);
 	gtk_widget_set_sensitive(button1,
-			strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0);
+		g_strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0);
 	gtk_widget_grab_focus(GTK_COMBO(combo0)->entry);
 	replace_clicked_button=REPLACE_CANCEL;
 
