@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -551,7 +551,7 @@ gboolean signal_button_press(GtkWidget *widget,
 					if (delete_list(&tmaid->redo)>0 || d->next==NULL
 																|| select.x<0)
 						set_menu_bar(tmaid);
-					tmaid->edit=TRUE;
+					tmaid_change_edit (tmaid, TRUE);
 					g_free(text);
 				} else {
 					/* 쥯ΥʡʬǤϤʤȤ */
@@ -1083,7 +1083,7 @@ gboolean signal_key_press(GtkWidget *widget,
 			tmaid->undo=d;
 			if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
 				set_menu_bar(tmaid);
-			tmaid->edit=TRUE;
+			tmaid_change_edit (tmaid, TRUE);
 		}
 		result=TRUE;
 		break;
@@ -1118,7 +1118,7 @@ gboolean signal_key_press(GtkWidget *widget,
 			tmaid->undo=d;
 			if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
 				set_menu_bar(tmaid);
-			tmaid->edit=TRUE;
+			tmaid_change_edit (tmaid, TRUE);
 		}
 		result=TRUE;
 		break;
@@ -1136,7 +1136,7 @@ gboolean signal_key_press(GtkWidget *widget,
 				if (delete_list(&tmaid->redo)>0
 											|| d->next==NULL || select.x>=0)
 					set_menu_bar(tmaid);
-				tmaid->edit=TRUE;
+				tmaid_change_edit (tmaid, TRUE);
 			} else {
 				gint page;
 				guint length;
@@ -1229,7 +1229,7 @@ gboolean signal_key_press(GtkWidget *widget,
 			tmaid->undo=d;
 			if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
 				set_menu_bar(tmaid);
-			tmaid->edit=TRUE;
+			tmaid_change_edit (tmaid, TRUE);
 		}
 		result=TRUE;
 		break;
@@ -1271,7 +1271,7 @@ gboolean signal_key_press(GtkWidget *widget,
 			tmaid->undo=d;
 			if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
 				set_menu_bar(tmaid);
-			tmaid->edit=TRUE;
+			tmaid_change_edit (tmaid, TRUE);
 		}
 		result=TRUE;
 		break;
@@ -1345,7 +1345,7 @@ gboolean signal_key_press(GtkWidget *widget,
 				if (delete_list(&tmaid->redo)>0
 											|| d->next==NULL || select.x>=0)
 					set_menu_bar(tmaid);
-				tmaid->edit=TRUE;
+				tmaid_change_edit (tmaid, TRUE);
 				result=TRUE;
 			}
 		}
@@ -1664,7 +1664,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 			tmaid->undo=d;
 			if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
 				set_menu_bar(tmaid);
-			tmaid->edit=TRUE;
+			tmaid_change_edit (tmaid, TRUE);
 			g_free(text);
 		}
 	} else if (data->selection==atom_textmaid0) {
@@ -1676,7 +1676,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 		argv=g_strsplit(data->data,"\n",G_MAXINT);
 		init_line=0;
 		arg_files=arg_analyse(argv,FALSE);
-		for (i=0;argv[i]!=NULL;i++)
+		for (i = 1; argv[i] != NULL; i++)
 			if (arg_files[i]) {
 				tmaid=file_open_edit(argv[i]);
 				if (init_line!=0)	/* Ԥ˰ư */
