@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "general.h"
 #include "jump.h"
 #ifdef USE_GDKPIXBUF
-#include "print.h"
+# include "print.h"
 #endif
 #include "replace.h"
 #include "signal.h"
@@ -43,7 +43,7 @@ gboolean caret=FALSE;				/* åȤη */
 gboolean ins=TRUE;					/* TRUE:,FALSE: */
 gboolean newfile=FALSE;				/* TRUE:ե,FALSE:ʤ */
 gboolean second=FALSE;				/* TRUE:,FALSE:¸ */
-gchar *history_files[10];					/* ե */
+gchar *history_files[10];			/* ե */
 gchar *open_path=NULL;				/* Υѥ */
 gchar *save_path=NULL;				/* ̾դ¸Υѥ */
 gchar *clipboard_text=NULL;			/* åץܡɤΥƥ */
@@ -379,7 +379,7 @@ int main(int argc,char *argv[])
 	}
 
 	/* ޥɥ饤β */
-	arg_files=arg_analyse(argv+1,TRUE);
+	arg_files=arg_analyse(argv,TRUE);
 
 	/* ե륿 */
 	if (ftnum<=0) {
@@ -523,21 +523,28 @@ int main(int argc,char *argv[])
 
 	/* ˵ưƤ뤫å */
 	if (!second) {
-		for (i=1;i<argc;i++) {
-			if (arg_files[i-1]) {
-				arg=misc_get_full_path(argv[i]);
-				leng=g_strlen(arg)*sizeof(gchar);
-				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
-				g_memmove(arg_text+length,arg,leng);
-				g_free(arg);
-			} else {
-				leng=g_strlen(argv[i])*sizeof(gchar);
-				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
-				g_memmove(arg_text+length,argv[i],leng);
-			}
-			length+=leng;
-			arg_text[length++]='\n';
-		}
+		if (argc > 1)
+			for (i = 0; i < argc; i++)
+			  {
+				if (arg_files[i])
+				  {
+					arg = misc_get_full_path (argv[i]);
+					leng = g_strlen (arg) * sizeof (gchar);
+					arg_text = g_realloc (arg_text,
+											length + leng + sizeof (gchar));
+					g_memmove (arg_text + length, arg, leng);
+					g_free (arg);
+				  }
+				else
+				  {
+					leng = g_strlen (argv[i]) * sizeof (gchar);
+					arg_text = g_realloc (arg_text,
+											length + leng + sizeof (gchar));
+					g_memmove (arg_text + length, argv[i], leng);
+				  }
+				length += leng;
+				arg_text[length++] = '\n';
+			  }
 		if (length>0) {
 			arg_text[length-1]='\0';
 			gtk_selection_owner_set(window,atom_textmaid1,GDK_CURRENT_TIME);
@@ -581,7 +588,7 @@ int main(int argc,char *argv[])
 
 	/* ɥ */
 	for (i=1;i<argc;i++)
-		if (arg_files[i-1]) {
+		if (arg_files[i]) {
 			tmaid=file_open_edit(argv[i]);
 			if (init_line!=0)	/* Ԥ˰ư */
 				jump_operation(tmaid,init_line);
