@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@
 #include "intl.h"
 
 
+#define TMAID_VERSION_NOTICE "Text maid "VERSION" ("TMAID_BUILD_ENVIRONMENT")"
+#define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2003 Kazuki IWAMOTO"
+
 #ifdef USE_GDKPIXBUF
 #define MENUFILE 12
 #else
@@ -105,6 +108,7 @@ typedef struct TmaidWindow_Tag {
 	GtkWidget *hscroll;			/* ʿС */
 	GtkWidget *vscroll;			/* ľС */
 	GtkWidget *label;			/* ֤Υ٥ */
+	GtkWidget *mark;			/* ֤ԽѤߥޡ */
 	GtkWidget *menu_item;		/* ˥塼Υɥι */
 } TmaidWindow;
 
